@@ -46,9 +46,14 @@
 #include "../network.h"
 #include "../printtext.h"
 #include "../strHand.h"
+#include "../strdup_printf.h"
 #include "../terminal.h"
 
 #include "connect.h"
+#include "i18n.h"
+#if defined(WIN32) && defined(printf)
+#undef printf
+#endif
 
 volatile bool g_disconnect_wanted = false;
 
@@ -202,7 +207,7 @@ shouldConnectUsingPassword(void)
 	char answer[20] = { '\0' };
 
 	while (true) {
-		printf("Connect using password? [Y/n]: ");
+		fputs(_("Connect using password? [Y/n]: "), stdout);
 		fflush(stdout);
 
 		if (fgets(answer, sizeof answer, stdin) == NULL) {
@@ -210,7 +215,7 @@ shouldConnectUsingPassword(void)
 		} else if (strchr(answer, '\n') == NULL) {
 			int c;
 
-			puts("input too big");
+			puts(_("input too big"));
 
 			while (c = getchar(), c != '\n' && c != EOF)
 				/* discard */;
@@ -239,7 +244,7 @@ get_password(void)
 		    sizeof pass)) == 0)
 			return (&pass[0]);
 		else {
-			err_log(errno, "%s: string copy error", __func__);
+			err_log(errno, _("%s: string copy error"), __func__);
 			return NULL;
 		}
 	}
@@ -255,7 +260,7 @@ get_password(void)
 		bool	fgets_error;
 		int	errno_save;
 
-		printf("Server password (will not echo): ");
+		fputs(_("Server password (will not echo): "), stdout);
 		fflush(stdout);
 
 		term_toggle_echo(OFF);
@@ -271,7 +276,7 @@ get_password(void)
 		} else if (strchr(pass, '\n') == NULL) {
 			int c;
 
-			puts("input too big");
+			puts(_("input too big"));
 
 			while (c = getchar(), c != '\n' && c != EOF)
 				/* discard */;
@@ -289,9 +294,10 @@ get_password(void)
 static PIRC_SERVER
 get_server_v2(PIRC_SERVER ptr, const size_t size, const char *hdr)
 {
-	PIRC_SERVER srv;
-	char ans[20] = { '\0' };
-	int i, srvno;
+	PIRC_SERVER	srv;
+	STRING		msg;
+	char		ans[20] = { '\0' };
+	int		i, srvno;
 
 	escape_curses();
 	puts(hdr);
@@ -307,8 +313,10 @@ get_server_v2(PIRC_SERVER ptr, const size_t size, const char *hdr)
 		i -= 1;
 	srvno = 0;
 	while (true) {
-		printf("Your choice (0-%d): ", i);
+		msg = strdup_printf(_("Your choice (0-%d): "), i);
+		fputs(msg, stdout);
 		fflush(stdout);
+		free(msg);
 
 /*
  * sscanf() is safe in this context
@@ -321,7 +329,7 @@ get_server_v2(PIRC_SERVER ptr, const size_t size, const char *hdr)
 		} else if (strchr(ans, '\n') == NULL) {
 			int c;
 
-			puts("input too big");
+			puts(_("input too big"));
 
 			while (c = getchar(), c != '\n' && c != EOF)
 				/* discard */;
@@ -533,8 +541,8 @@ do_connect(const char *server, const char *port, const char *pass)
 
 		while (net_connect(&conn_ctx, &sleep_time_seconds) ==
 		    SHOULD_RETRY_TO_CONNECT) {
-			printtext(&ptext_ctx, "Next reconnect attempt in %ld "
-			    "seconds...", sleep_time_seconds);
+			printtext(&ptext_ctx, _("Next reconnect attempt in %ld "
+			    "seconds..."), sleep_time_seconds);
 
 			for (long int secs = 0;
 			    secs < sleep_time_seconds;
@@ -544,8 +552,8 @@ do_connect(const char *server, const char *port, const char *pass)
 				if (quit_reconnecting) {
 					net_kill_connection();
 					net_connect_clean_up();
-					printtext(&ptext_ctx, "Reconnection "
-					    "aborted!");
+					printtext(&ptext_ctx, "%s",
+					    _("Reconnection aborted!"));
 					goto out_of_both_loops;
 				}
 			}
