@@ -80,21 +80,21 @@
 #include "ToastsAPI.hpp"
 #endif
 
-#define DUP_OPTION_ERR(opt)	err_quit("A duplicate of option -%c found", opt)
+#define DUP_OPTION_ERR(opt)	err_quit(_("A duplicate of option -%c found"), opt)
 #define PUTCHAR(c)		((void) fputc(c, stdout))
 #define PUTS(string)		((void) fputs(string, stdout))
 
 /* Things with external linkage
    ============================ */
 
-chararray_t	g_swircVersion	= "v3.4.9";
+chararray_t	g_swircVersion	= "v3.5.0";
 chararray_t	g_swircYear	= "2012-2024";
 chararray_t	g_swircAuthor	= "Markus Uhlin";
 chararray_t	g_swircWebAddr	= "https://www.nifty-networks.net/swirc/";
 
 FILE		*g_dev_null = nullptr;
-char		*g_progname = const_cast<char *>("");
-char		*g_progpath = nullptr;
+STRING		 g_progname = const_cast<STRING>("");
+STRING		 g_progpath = nullptr;
 long int	 g_pid = -1;
 
 int	 g_stderr_fd = -1;
@@ -165,7 +165,7 @@ static stringarray_t OptionDesc = {
 static void
 swirc_terminate()
 {
-	err_msg("Unhandled exception!");
+	err_msg("%s", _("Unhandled exception!"));
 	abort();
 }
 
@@ -175,7 +175,7 @@ swirc_terminate()
 static void
 view_version()
 {
-	char *MessageVersion;
+	STRING MessageVersion;
 
 	MessageVersion = strdup_printf("Swirc %s\nCopyright (C) %s %s. "
 	    "All rights reserved.\n%s %s\n",
@@ -221,9 +221,9 @@ view_version()
  * Print help
  */
 static void
-print_help(const char *exe)
+print_help(CSTRING exe)
 {
-	char *MessageUsage;
+	STRING MessageUsage;
 
 	MessageUsage = strdup_printf(_("Usage: %s [OPTION] ...\n"), exe);
 	PUTS(MessageUsage);
@@ -251,21 +251,21 @@ case_launched_by_toast_hook()
 static void
 case_connect()
 {
-	char		*last = const_cast<char *>("");
-	char		*token1, *token2;
-	static bool	 been_case = false;
+	CSTRING		token[2];
+	STRING		last = const_cast<STRING>("");
+	static bool	been_case = false;
 
 	if (been_case)
 		DUP_OPTION_ERR('c');
 
-	token1 = strtok_r(g_option_arg, ":", &last);
-	sw_assert(token1 != nullptr);
-	g_cmdline_opts->server = sw_strdup(token1);
+	token[0] = strtok_r(g_option_arg, ":", &last);
+	sw_assert(token[0] != nullptr);
+	g_cmdline_opts->server = sw_strdup(token[0]);
 
-	if ((token2 = strtok_r(nullptr, ":", &last)) == nullptr)
+	if ((token[1] = strtok_r(nullptr, ":", &last)) == nullptr)
 		g_cmdline_opts->port = sw_strdup("6667");
 	else
-		g_cmdline_opts->port = sw_strdup(token2);
+		g_cmdline_opts->port = sw_strdup(token[1]);
 
 	g_auto_connect = been_case = true;
 }
@@ -315,7 +315,7 @@ case_join()
 		if ((token = strtok_r(cp, ",", &last)) == nullptr)
 			break;
 		else if (strpbrk(token, g_forbidden_chan_name_chars) != nullptr)
-			err_quit("forbidden chan name chars");
+			err_quit("%s", _("forbidden channel name characters"));
 		else
 			g_join_list.push_back(token);
 	}
@@ -464,12 +464,12 @@ process_options(int argc, char *argv[], const char *optstring)
 			case_config();
 			break;
 		case UNRECOGNIZED_OPTION:
-			err_msg("%s: -%c: unrecognized option", argv[0],
+			err_msg(_("%s: -%c: unrecognized option"), argv[0],
 			    g_option_save);
 			print_help(argv[0]);
 			exit(EXIT_FAILURE);
 		case OPTION_ARG_MISSING:
-			err_msg("%s: -%c: option argument missing", argv[0],
+			err_msg(_("%s: -%c: option argument missing"), argv[0],
 			    g_option_save);
 #if defined(__cplusplus) && __cplusplus >= 201703L
 			[[fallthrough]];
@@ -626,7 +626,7 @@ main(int argc, char *argv[])
 #endif
 
 	if (!sighand_init()) {
-		err_msg("fatal: failed to initialize signal handling");
+		err_msg("%s", _("fatal: failed to initialize signal handling"));
 		return EXIT_FAILURE;
 	}
 
@@ -648,8 +648,8 @@ main(int argc, char *argv[])
 
 #if UNIX
 	if (geteuid() == 0) {
-		err_msg("fatal: running the program with root privileges is "
-		    "forbidden");
+		err_msg("%s", _("fatal: running the program with root "
+		    "privileges is forbidden"));
 		return EXIT_FAILURE;
 	}
 #endif
@@ -658,6 +658,11 @@ main(int argc, char *argv[])
 
 	srand(get_seed());
 
+#if TEST_XWCWIDTH
+#pragma message("warning: test included (not to be used in production)")
+	(void) xwcwidth(L'\0', 7357);
+#endif
+
 	term_init();
 	nestHome_init();
 
@@ -669,7 +674,8 @@ main(int argc, char *argv[])
 #endif
 
 	if (curses_init() != OK) {
-		err_msg("Initialization of the Curses library not possible");
+		err_msg("%s", _("Initialization of the Curses library not "
+		    "possible"));
 		return EXIT_FAILURE;
 	}
 
