@@ -73,8 +73,8 @@ extern chararray_t	g_swircAuthor;
 extern chararray_t	g_swircWebAddr;
 
 extern FILE		*g_dev_null;
-extern char		*g_progname;
-extern char		*g_progpath;
+extern STRING		 g_progname;
+extern STRING		 g_progpath;
 extern long int		 g_pid;
 
 extern int	 g_stderr_fd;
